@@ -40,7 +40,7 @@
 #' }
 #' For additional details, see the vignette.
 #' @references
-#' Battaglini M., V. Leone Sciabolazza, E. Patacchini, S. Peng (2018), "Econet: An R package for the Estimation of parameter.dependent centrality measures", NBER Working Paper (24442). \cr
+#' Battaglini M., V. Leone Sciabolazza, E. Patacchini, S. Peng (2020), "Econet: An R package for the Estimation of parameter-dependent centrality measures", Mimeo. \cr
 #' @seealso \code{\link{net_dep}}
 #' @examples
 #' \donttest{
@@ -267,7 +267,7 @@ horse_race <- function(
     if (!is.null(exclusion_restriction)) {
       second_step_list[[length(second_step_list) + 1]] <- hr[[1]]
       names(second_step_list) <- c(centralities, "parameter.dependent")
-      first_step_list[[length(second_step_list) + 1]] <- first_step
+      first_step_list[[length(first_step_list) + 1]] <- first_step
       names(first_step_list) <- c(first_step_list, "parameter.dependent")
       second_step_cent_mes <- data.frame(second_step_cent_mes,
                                          "parameter.dependent" = hr[[2]])
